@@ -3,7 +3,7 @@ package Specio::Constraint::AnyIsa;
 use strict;
 use warnings;
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 use B ();
 use Role::Tiny::With;
@@ -24,13 +24,15 @@ with 'Specio::Constraint::Role::IsaType';
         my $self = shift;
         my $val  = shift;
 
-        return sprintf( <<'EOF', ($val) x 3, B::perlstring( $self->class ) );
+        return sprintf( <<'EOF', ($val) x 5, B::perlstring( $self->class ) );
 (
     (
         Scalar::Util::blessed( %s )
         ||
         (
-            !ref( %s )
+            defined( %s )
+            && !ref( %s )
+            && length( %s )
         )
     )
     &&
@@ -42,6 +44,10 @@ EOF
     sub _build_inline_generator {$_inline_generator}
 }
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
+sub _allow_classes {1}
+## use critic
+
 __PACKAGE__->_ooify;
 
 1;
@@ -60,7 +66,7 @@ Specio::Constraint::AnyIsa - A class for constraints which require a class name
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 SYNOPSIS
 
