@@ -3,9 +3,10 @@ package Specio::Constraint::Role::DoesType;
 use strict;
 use warnings;
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 use Role::Tiny;
+use Scalar::Util qw( blessed );
 use Specio::PartialDump qw( partial_dump );
 use Storable qw( dclone );
 
@@ -39,24 +40,44 @@ sub _wrap_message_generator {
     my $self      = shift;
     my $generator = shift;
 
-    my $role = $self->role;
+    my $type          = ( split /::/, blessed $self)[-1];
+    my $role          = $self->role;
+    my $allow_classes = $self->_allow_classes;
 
     unless ( defined $generator ) {
         $generator = sub {
-            my $description = shift;
-            my $value       = shift;
+            shift;
+            my $value = shift;
 
-            return
-                  "Validation failed for $description with value "
-                . partial_dump($value)
-                . '(does not do '
-                . $role . ')';
+            return "An undef will never pass an $type check (wants $role)"
+                unless defined $value;
+
+            if ( ref $value && !blessed $value ) {
+                my $dump = partial_dump($value);
+                return
+                    "An unblessed reference ($dump) will never pass an $type check (wants $role)";
+            }
+
+            if ( !blessed $value) {
+                return
+                    "An empty string will never pass an $type check (wants $role)"
+                    unless length $value;
+
+                if ( !$allow_classes ) {
+                    my $dump = partial_dump($value);
+                    return
+                        "A plain scalar ($dump) will never pass an $type check (wants $role)";
+                }
+            }
+
+            my $got = blessed $value;
+            $got ||= $value;
+
+            return "The $got class does not consume the $role role";
         };
     }
 
-    my $d = $self->description;
-
-    return sub { $generator->( $d, @_ ) };
+    return sub { $generator->( undef, @_ ) };
 }
 ## use critic
 
@@ -76,7 +97,7 @@ Specio::Constraint::Role::DoesType - Provides a common implementation for Specio
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 DESCRIPTION
 
